NXSConfigServer Tango Class Attributes

NXSConfigServer Class Attributes
Name | Inherited | Abstract | Attr. type | R/W type | Data type | Level | Description
XMLString | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | It allows to pass XML strings into database during performing StoreComponent and StoreDataSource Moreover, after performing CreateConfiguration it contains the resulting XML configuration.
Selection | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | "It allows to pass JSON strings into database during performing StoreSelection.
JSONSettings | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | "The JSON string with parameters of MySQLdb.connect(...).
Version | false | false | Scalar | READ | Tango::DEV_STRING | OPERATOR | Configuration version
Variables | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | The JSON string with XML configuration variables
STEPDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to be switched into STEP mode during creating configuration process
LinkDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to which links will be added
CanFailDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to be switched into CanFail mode during creating configuration process
ExtraLinkDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to which links will be added
XMLCache | false | false | Scalar | READ | Tango::DEV_STRING | EXPERT | XML for merged components without applied variables

There is no dynamic attribute defined.